@@ -6,15 +6,11 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-from .cookieidentifieddistributedsession import CookieIdentifiedDistributedSession
-from .publicresource import PublicResource
-from .resource import Resource
-from .sessionendpoint import SessionEndpoint
+from .apiresource import APIResource
+from .sessionresource import SessionResource
 
 
 __all__: list[str] = [
-    'CookieIdentifiedDistributedSession',
-    'PublicResource',
-    'Resource',
-    'SessionEndpoint',
+    'APIResource',
+    'SessionResource',
 ]
\ No newline at end of file
